# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

ort_run <- function(session_ptr, input_array, input_shape, input_name, output_name) {
    .Call(`_nativeORT_ort_run`, session_ptr, input_array, input_shape, input_name, output_name)
}

ort_version <- function() {
    .Call(`_nativeORT_ort_version`)
}

ort_create_env <- function() {
    .Call(`_nativeORT_ort_create_env`)
}

ort_create_session <- function(env_ptr, model_path, provider = "cpu", cache_dir = "", threads = 0L, opt_level = 99L) {
    .Call(`_nativeORT_ort_create_session`, env_ptr, model_path, provider, cache_dir, threads, opt_level)
}

ort_session_input_count <- function(session_ptr) {
    .Call(`_nativeORT_ort_session_input_count`, session_ptr)
}

ort_session_output_count <- function(session_ptr) {
    .Call(`_nativeORT_ort_session_output_count`, session_ptr)
}

ort_session_input_names <- function(session_ptr) {
    .Call(`_nativeORT_ort_session_input_names`, session_ptr)
}

ort_session_output_names <- function(session_ptr) {
    .Call(`_nativeORT_ort_session_output_names`, session_ptr)
}

