% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/install.R
\name{ort_binary_url}
\alias{ort_binary_url}
\title{ort_binary_url}
\usage{
ort_binary_url()
}
\value{
string where to download onnxruntime from
}
\description{
ort_binary_url
}
\examples{
ort_binary_url()
}
