% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/install.R
\name{ort_install_dir}
\alias{ort_install_dir}
\title{ort_install_dir}
\usage{
ort_install_dir()
}
\value{
where the install lives
}
\description{
ort_install_dir
}
\examples{
ort_install_dir()
}
