% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/install.R
\name{ort_detect_os}
\alias{ort_detect_os}
\title{ort_detect_os}
\usage{
ort_detect_os()
}
\value{
str - platform
}
\description{
ort_detect_os
}
\examples{
ort_detect_os()
}
