% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/install.R
\name{ort_install}
\alias{ort_install}
\title{ort_install}
\usage{
ort_install()
}
\value{
invisible where it was saved to
}
\description{
ort_install
}
\examples{
\donttest{
  if(!ort_is_installed()){
    ort_install()}
  }
}
